Package: neuroimaGene
Type: Package
Title: Transcriptomic Atlas of Neuroimaging Derived Phenotypes
Version: 0.1.4
Authors@R: c(person("Xavier", "Bledsoe", 
                    email = "xbledsoe22@gmail.com", 
                    role = c("aut", "cre"),
                    comment = c(ORCID = "0000-0002-6091-9372")),
            person("Eric", "Gamazon", 
                    email = "egamazon@vumc.org", 
                    role = c("aut"),
                    comment = c(ORCID = "0000-0003-4204-8734")))
Maintainer: Xavier Bledsoe <xbledsoe22@gmail.com>
Description: Contains functions to query and visualize the Neuroimaging features 
  associated with genetically regulated gene expression (GReX). The primary utility,
  neuroimaGene(), relies on a list of user-defined genes and returns a table of
  neuroimaging features (NIDPs) associated with each gene. This resource 
  is designed to assist in the interpretation of genome-wide and transcriptome-wide
  association studies that evaluate brain related traits. Bledsoe (2024) 
  <doi:10.1016/j.ajhg.2024.06.002>. In addition there are several visualization 
  functions that generate summary plots and 2-dimensional visualizations of regional 
  brain measures. Mowinckel (2020).
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
Imports: data.table, ggplot2, DBI, stringr, ggseg, sf, RSQLite
Depends: R (>= 3.5.0)
RoxygenNote: 7.3.3
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-29 04:12:40 UTC; xbledsoe
Author: Xavier Bledsoe [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6091-9372>),
  Eric Gamazon [aut] (ORCID: <https://orcid.org/0000-0003-4204-8734>)
Repository: CRAN
Date/Publication: 2026-04-29 15:10:09 UTC
Built: R 4.5.2; ; 2026-04-29 15:39:32 UTC; unix

# Generated by roxygen2: do not edit by hand

export(check_db)
export(listNIDPs)
export(neuro_vis)
export(neuroimaGene)
export(plot_gnNIDP)
export(plot_gns)
export(plot_nidps)
import(DBI)
import(RSQLite)
import(data.table)
import(ggplot2)
import(ggseg)
import(sf)
import(stringr)
importFrom(stats,na.omit)
importFrom(tools,md5sum)
importFrom(utils,download.file)
importFrom(utils,write.table)

#' NIDP summary plot of NeuroimaGene object
#'
#' Generate overview plot of the neuroimagene object according to nidps
#' @param ng_obj NeuroimaGene Object
#' @param maxNidps maximum number of NIDPs to visualize. default=30
#' @param title optional title tag for the plot
#' @param shortnames optional boolean tag for simplified names. Default to TRUE
#' @param mag boolean to present effect sizes by magnitude rather than as a vector. Default to TRUE
#' @param verbose print runtime messages to R console. Default to FALSE
#' @keywords neuroimaging
#' @export
#' @import data.table ggplot2
#' @returns a ggplot class object detailing mean effect size magnitude per NIDP, colored by brain region
#' @examples
#' gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
#' ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
#' plot_nidps(ng)
#'
plot_nidps <- function(ng_obj, maxNidps = 30, title = NA, shortnames = TRUE, mag = TRUE, verbose = FALSE) {
  # initialize column names as null variables
  zscore <- meanZ <- gwas_phenotype <- secondary <- NIDP <- NULL

  if(is.na(title)){
    tag <- ''
  } else {
    tag <- paste(' ',as.character(title))
  }
  if(!(is.integer(maxNidps) || is.double(maxNidps))) {
    stop('maxNidps must be of data.type: integer or double', call. = F)
  }
  ng_summ <- ng_obj[, list(meanZ = mean(zscore), sign = sign(mean(zscore))),
                by = c('gwas_phenotype')]

  ng <- data.table::setDT(merge(ng_summ, anno, by = 'gwas_phenotype'))
  utils::head(ng)
  if (length(unique(ng$gwas_phenotype)) > maxNidps ) {
    if(verbose){message(paste('WARNING: Greater than', maxNidps, 'NIDPs detected in input data. Plot will only show the top', maxNidps, 'NIDPs ranked by effect size magnitude'))}
    nidps <- ng[order(-abs(meanZ))][1:maxNidps,]$gwas_phenotype
    ng <- ng[gwas_phenotype %in% nidps,]
  }

  if(shortnames == FALSE) {
    ng <- ng[, -c('NIDP')]
    setnames(ng, 'gwas_phenotype', 'NIDP')
  }
  
  
  if(mag == TRUE) {
    ng$meanZ <- abs(ng$meanZ)
    axis_label <- 'Normalized effect size magnitude'
  } else {
    axis_label = 'Normalized effect size'
  }
  
  gn_plot <- ggplot2::ggplot(ng, aes(x = NIDP, y = meanZ, color= secondary, group = as.character(sign))) +
    geom_point(aes(shape=as.character(sign)), size = 4) + #size=as.character(gn_ct))) +
    theme_light()+
    ggtitle(paste0("Mean Effect Size per NIDP across\nall genes", tag)) +
    xlab('NIDPs') +
    ylab(axis_label) +
    theme_light() +
    theme(axis.text.x = element_text(angle = 0, size = 11, hjust = 0.5, vjust =0.5),
          axis.text.y = element_text(size = 11),
          plot.title = element_text(hjust = 0.5),
          plot.title.position = "plot",
    ) +
    scale_shape_discrete(name  ="sign",
                         breaks=c("1", "-1"),
                         labels=c("pos", "neg")) +
    coord_flip()

  return(gn_plot)
}

#' Gene by NIDP summary plot of neuroimaGene object
#'
#' Generate overview plot of the neuroimagene object according to gene/NIDP pair
#' @param ng_obj NeuroimaGene object
#' @param maxGns maximum number of genes to visualize. default=15
#' @param maxNidps maximum number of NIDPs to visualize. default=20
#' @param title optional title tag for the plot
#' @param shortnames optional boolean tag for simplified names. Default to TRUE
#' @param verbose print runtime messages to R console. Default to FALSE
#' @keywords neuroimaging
#' @export
#' @import data.table ggplot2
#' @returns a ggplot class heatmap showing tissue models per NIDP/Gene pair
#' @examples
#' gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
#' ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
#' plot_gnNIDP(ng)
#'
plot_gnNIDP <- function(ng_obj, maxNidps = 20, maxGns = 15, title = NA, shortnames = TRUE, verbose = FALSE) {
  # initialize column names as null variables
  zscore <- maxZ <- gwas_phenotype <- gene_name <- training_model <- tm_ct <- NIDP <- NULL

  if(is.na(title)){
    tag <- ''
  } else {
    tag <- paste(' ',as.character(title))
  }
  if(!(is.integer(maxNidps) || is.double(maxNidps))) {
    stop('maxNidps must be of data.type: integer or double', call. = F)
  }
  if(!(is.integer(maxGns) || is.double(maxGns))) {
    stop('maxNidps must be of data.type: integer or double', call. = F)
  }
  if (length(unique(ng_obj$gwas_phenotype)) > maxNidps ) {
    if(verbose){message(paste('WARNING: Greater than', maxNidps, 'NIDPs detected in input data. Plot will only show the top', maxNidps, 'NIDPs ranked by effect size magnitude'))}
    nidps <- ng_obj[, list(maxZ = max(zscore)), by = 'gwas_phenotype'][order(-abs(maxZ))][1:maxNidps,]$gwas_phenotype
    ng_obj <- ng_obj[gwas_phenotype %in% nidps,]
  }

  if (length(unique(ng_obj$gene)) > maxGns ) {
    if(verbose){message(paste('WARNING: Greater than', maxGns, 'genes remaining in input data after nidp analysis. Plot will only show the top', maxGns, 'genes ranked by effect size magnitude'))}
    genes <- ng_obj[, list(maxZ = max(zscore)), by = 'gene_name'][order(-abs(maxZ))][1:maxGns,]$gene_name
    ng_obj <- ng_obj[gene_name %in% genes,]
  }

  ng <- data.table::setDT(merge(ng_obj, anno, by = 'gwas_phenotype'))
  gn_nidp <- ng[, list(tm_ct = length(unique(training_model))),
                by = c('gene_name', 'gwas_phenotype', 'NIDP')]
  
  if(shortnames == FALSE) {
    gn_nidp <- gn_nidp[, -c('NIDP')]
    setnames(gn_nidp, 'gwas_phenotype', 'NIDP')
  }
  
  gn_plot <- ggplot2::ggplot(gn_nidp, aes(x = gene_name, y = NIDP, fill = tm_ct)) +
    geom_tile(color = 'white') +
    theme_light()+
    ggtitle(paste0('Neuroimaging correlates of GReX', tag)) +
    theme(axis.text.x = element_text(angle = 60, hjust = 1, size = 11),
          axis.text.y = element_text(size = 11)) +
    xlab('gene') +
    ylab('NIDPs') +
    labs(fill='JTI model\ncount')

  return(gn_plot)
}

#' NeuroimaGene object for vignette illustration
#'
#' NeuroimaGene data table containing select associations used in the package vignette.
#'
#' @docType data
#' @name ng_vignette
#' @usage data(ng_vignette)
#' @format A data.table with 6 columns and 3824 rows:
#' \describe{
#'   \item{gene}{character: ENSEMBL Gene ID}
#'   \item{gene_name}{character: HUGO gene name}
#'   \item{gwas_phenotype}{character: neuroimaging derived phenotype}
#'   \item{training_model}{character: JTI derived tissue gene expression model}
#'   \item{zscore}{numeric: normalized effect size of GReX on NIDP morphology}
#'   \item{mod_BHpval}{character: Benjamini Hochberg corrected pvalue corrected by modality }
#' }
#' @source Bledsoe, X. (2024) A transcriptomic atlas of the human brain reveals genetically determined aspects of neuropsychiatric health
#' @returns This script has no return. This is a documentation file for the
#' neuroimaGene data subset required to build the vignette.
NULL

#' NIDP annotation data
#'
#' annotation data for all NIDPs taken from the UKbiobank
#'
#' @docType data
#' @name anno
#' @format A data.table with 10 columns and 3935 rows:
#' \describe{
#'   \item{gwas_phenotype}{character: UKB-derived neuroimaging derived phenotype (NIDP)}
#'   \item{modality}{character: MRI neuroimaging modality}
#'   \item{atlas}{character: neuroimaging cortical atlas}
#'   \item{side}{character: right or left hemisphere or midline/whole brain}
#'   \item{primary}{character: primary cortical region}
#'   \item{secondary}{character: secondary cortical region}
#'   \item{region}{character: named region of the brain}
#'   \item{measurement}{character: morphology measurement}
#'   \item{fMRI_node_1}{character: fMRI node 1}
#'   \item{fMRI_node_2}{character: fMRI node 2}
#'   \item{NIDP}{character: user-friendly name for each NIDP}
#' }
#' @source Bledsoe, X. (2024) A transcriptomic atlas of the human brain reveals genetically determined aspects of neuropsychiatric health
#' @returns This script has no return. This is a documentation file for the
#' annotation dataset for all neuroimaging derived phenotypes.
NULL

#' 2D visualization plot of a neuroimaGene object
#'
#' Generates a 2D visualization plot of the neuroimaGene object. Neuroimaging
#' regions are defined by the atlas parameter and colored according to the
#' magnitude and direction of the aggregate effect from each gene in the
#' NeuroimaGene object. Colors can be defined by the user.
#'
#' @param ng_obj NeuroimaGene object produced by neuroimaGene() function
#' @param atlas desired atlas for visualization. Desikan (default), Subcortex, DKT, Destrieux.
#' @param lowcol color for low end of Zscore spectrum. Default is red
#' @param midcol color for middle of Zscore spectrum. Default is white
#' @param highcol color for top end of Zscore spectrum. Default is blue
#' @param title optional title tag for the plot
#' @keywords neuroimaging
#' @export
#' @import data.table ggplot2 stringr ggseg sf
#' @importFrom utils write.table
#' @importFrom stats na.omit
#' @returns class: ggplot object depicting 2D visualization of the NIDPs from the neuroimaGene object portrayed on the brain and shaded by mean effect size.
#' @examples
#' gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
#' ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
#' neuro_vis(ng, atlas = 'DKT')
#'
#'
neuro_vis <- function(ng_obj, atlas = 'Desikan', lowcol = 'red2', midcol = 'white', highcol = 'royalblue2', title = NA) {
  # initialize column names as null variables
  zscore <- atlasnm <- atl <- gwas_phenotype <- meanZ <- measurement <- x <- y <- label <- NULL
  
  # load required local data from package
  dkt_atl <- readRDS(system.file("extdata","dkt_atlas_new.rda", package = "neuroimaGene"))
  dest_atl <- readRDS(system.file("extdata","dest_atlas_new.rda", package = "neuroimaGene"))
  
  if(is.na(title)){
    tag <- ''
  } else {
    tag <- paste(' ',as.character(title))
  }
  ng_summ <- ng_obj[, list(meanZ = mean(zscore), sign = sign(mean(zscore))),
                    by = c('gwas_phenotype')]
  ng <- data.table::setDT(merge(ng_summ, anno[, c('gwas_phenotype', 'measurement')], by = 'gwas_phenotype'))
  ng <- data.table::setDT(merge(ng, fs_anno, by = 'gwas_phenotype'))
  
  
  atldir <- data.table::data.table(atlasnm = c('Desikan', 'DKT', 'Destrieux', 'Subcortex',
                                               'desikan', 'dkt', 'destrieux', 'subcortex'),
                                   realname =c('Desikan', 'DKT', 'Destrieux', 'Subcortex',
                                               'Desikan', 'DKT', 'Destrieux', 'Subcortex'),
                                   fsatl = c('ggseg::dk()', 'dkt_atl',
                                             'dest_atl','ggseg::aseg()',
                                             'ggseg::dk()', 'dkt_atl',
                                             'dest_atl','ggseg::aseg()'),
                                   fsnm = c('dk', 'dkt', 'destrieux', 'aseg',
                                            'dk', 'dkt', 'destrieux', 'aseg'))
  atlname = atldir[atlasnm == atlas,]$realname
  fs = atldir[atlasnm == atlas,]$fsatl
  fs2 = atldir[atlasnm == atlas,]$fsnm
  stat_vis <- stats::na.omit(ng[atl == atlname,])
  
  if (dim(stat_vis)[1] == 0) {
    stop(paste0('No nidps from the',atlas,'atlas detected.'))
  }
  
  if (atlas == 'Subcortex' ) {
    # plot aseg volumes
    aseg_vol <- stat_vis[gwas_phenotype %like% 'volume' & atl == 'Subcortex',]
    brain_plot2 <- ggplot(aseg_vol) +
      geom_brain(atlas = aseg(), aes(fill = meanZ), position = position_brain(nrow = 2)) +
      ggtitle(paste0('Subcortical NIDPs (aseg atlas)', tag))+
      scale_fill_gradient2(low = lowcol, mid = midcol, high = highcol, na.value = "lightgrey", name = "meanZ") +
      annotate_brain(atlas = aseg(), position = position_brain(nrow = 2), colour = "grey30",
                     family = "sans") +
      theme_void()
    
  } else if (atlas == 'Desikan'){
    
    measures = unique(stat_vis$measurement[!is.na(stat_vis$measurement)])
    stat_vis_final <- data.table::data.table()
    for(msr in measures) {
      temp1 <- data.table::as.data.table(merge(stat_vis[measurement == msr,],
                                               data.table::as.data.table(dk()$data$vertices)[,c('label', 'vertices')],
                                               by = c('label'),
                                               all.y = TRUE))
      
      temp1$measurement <- msr
      stat_vis_final = rbind(stat_vis_final, temp1)
    }
    stat_vis_final$atlas <- fs2
    
    pos <- position_brain(hemi ~ view)
    brain_plot <- ggplot(stat_vis_final) +
      geom_brain(atlas = dk(), aes(fill = meanZ), position = pos) +
      scale_fill_gradient2(low = lowcol, mid = midcol, high = highcol, na.value = "lightgrey", name = "meanZ") +
      facet_wrap(~measurement, nrow = length(unique(stat_vis_final$measurement))) +
      theme_void()
    
    bp <- ggplot_build(brain_plot)
    top_x <- max(bp$layout$panel_params[[1]]$x$breaks)
    top_y <- max(bp$layout$panel_params[[1]]$y$breaks)
    
    col_labels <- data.frame(
      x = c((top_x/8), (3*top_x)/8, (5*top_x)/8, (7*top_x)/8),  
      y = -top_y/20,                  
      label = c("inferior", "lateral", "medial", "superior")
    )
    row_labels <- data.frame(
      x = 0 ,#-top_x/20,                 
      y = c(top_y/4, (3*top_y)/4),        
      label = c("right", "left")
    )
    
    brain_plot2 <- ggplot(stat_vis_final) +
      geom_brain(atlas = dk(), aes(fill = meanZ), position = pos) +
      geom_text(data = col_labels, aes(x = x, y = y, label = label),
                size = 3, colour = "grey30",
                family = "sans") +
      geom_text(data = row_labels, aes(x = x, y = y, label = label),
                size = 3,  colour = "grey30",
                family = "sans", angle = 90, vjust =-1) +
      ggtitle(paste0(atlas, ' atlas NIDPs', tag))+
      scale_fill_gradient2(low = lowcol, mid = midcol, high = highcol, na.value = "lightgrey", name = "meanZ") +
      facet_wrap(~measurement, nrow = length(unique(stat_vis_final$measurement)), strip.position="left") +
      theme_void() +
      theme(strip.text = element_text(face = "bold", family = 'sans', size = 10, angle = 90),
            strip.background = element_rect(fill="grey90"))
    
  } else {
    
    measures = unique(stat_vis$measurement[!is.na(stat_vis$measurement)])
    atlas_joined <- sf::st_sf(geometry = sf::st_sfc())
    for(msr in measures) {
      temp <- data.table::as.data.table(merge(stat_vis[measurement == msr,],
                                              data.table::as.data.table(eval(parse(text = fs))$data$sf),
                                              by = c('label'),
                                              all.y = TRUE))
      temp$measurement <- msr
      atlas_joined = rbind(atlas_joined, sf::st_as_sf(temp))
    }
    atlas_joined$atlas <- fs2
    
    brain_plot <- ggplot(atlas_joined) +
      geom_sf(aes(fill = meanZ)) +
      scale_fill_gradient2(low = lowcol, mid = midcol, high = highcol,
                           na.value = "lightgrey", name = "meanZ") +
      facet_wrap(~measurement, nrow = length(unique(measures)), strip.position="left") +
      theme_void()
    
    bp <- ggplot_build(brain_plot)
    top_x <- max(bp$layout$panel_params[[1]]$x$breaks)
    top_y <- max(bp$layout$panel_params[[1]]$y$breaks)
    
    col_labels <- data.frame(
      x = c((top_x/8), (3*top_x)/8, (5*top_x)/8, (7*top_x)/8),  # x center of each column
      y = -top_y/10,                  # just above the top row
      label = c("L lateral", "L medial", "R medial", "R Lateral")
    )
    
    brain_plot2 <- ggplot(atlas_joined) +
      geom_sf(aes(fill = meanZ)) +
      geom_text(data = col_labels, aes(x = x, y = y, label = label),
                size = 3, colour = "grey30",
                family = "sans") +
      ggtitle(paste0(atlas, ' atlas NIDPs', tag))+
      scale_fill_gradient2(low = lowcol, mid = midcol, high = highcol,
                           na.value = "lightgrey", name = "meanZ") +
      facet_wrap(~measurement, nrow = length(unique(measures)), strip.position="left") +
      theme_void() +
      theme(strip.text = element_text(face = "bold", family = 'sans', size = 10, angle = 90),
            strip.background = element_rect(fill="grey90"))
    
    
  }
  return(brain_plot2)
}

#' NIDP freesurfer annotation data
#'
#' Freesurfer names for select cortical and subcortical NIDPs
#' @docType data
#' @name fs_anno
#' @usage data(fs_anno)
#' @format A data.table with 7 columns and 890 rows:
#' \describe{
#'   \item{gwas_phenotype}{character: UKB-derived neuroimaging derived phenotype}
#'   \item{atl}{character: neuroimaging cortical atlas}
#'   \item{hemisphere}{character: right or left hemisphere or midline/whole brain}
#'   \item{secondary}{character: secondary cortical region}
#'   \item{fs_name}{character: freesurfer name}
#'   \item{label}{character: label name for the region}
#'   \item{atlas}{character: freesurfer name for neuroimaging cortical atlas}
#' }
#' @source Bledsoe, X. (2024) A transcriptomic atlas of the human brain reveals genetically determined aspects of neuropsychiatric health
#' @returns This script has no return. This is a documentation file for the
#' annotation dataset for all neuroimaging derived phenotypes in the fsbrain package.
NULL

#' Check neuroimaGene database downloaded
#'
#' Check if the NeuroimaGene database exists in the proper location prior to running the query and prompt user to download if not.
#' @keywords installation
#' @param timeout time to spend downloading the NeuroimaGene database in seconds (default = 900)
#' @param localdb path to local copy of NeuroimaGenefast.db file (default = NA)
#' @export
#' @importFrom utils download.file
#' @importFrom tools md5sum
#' @returns no return value, called to give information on status of neuroimaGene
#' database and prompt user the user to download if resource file is missing.
#' @examples
#' check_db(timeout = 600)



# Define the function to check and download the database
check_db <- function(timeout=900, localdb = NA) {
  
  pkg_dir <- system.file(package = "neuroimaGene")
  db_path <- file.path(pkg_dir, "extdata", "NeuroimaGenefast.db")
  db_url <- "https://zenodo.org/records/10994978/files/NeuroimaGenefast.db"
  
  
  #Download local copy of neuroimaGene SQL database as specified by user
  if (!is.na(localdb)){    
    if (tools::md5sum(localdb) == '60dab0d523b046f242c0c0f34d918b76') { #check md5 of local file
      message("md5 of local db file passes internal check. integrating file into package data")
      file.rename(from = localdb, to = db_path)
      if (tools::md5sum(db_path) == '60dab0d523b046f242c0c0f34d918b76') {
        message("neuroimaGene SQL database integrated into package data")
      } else {
        message("neuroimaGene SQL database integration was unsuccessful. See documentation for troubleshooting.")
      }
    } else { 
      message("md5 of local db file does not pass internal check. neuroimaGene SQL file may be corrupted or incorrect file")
      response <- readline(prompt = "Would you like to proceed using specified file? (yes/no): ")
      if (tolower(response) == "yes") {
        file.rename(from = localdb, to = db_path)
      } else {
        message("neuroimaGene SQL database integration was unsuccessful. See documentation for troubleshooting.")
      }
    }
  } else if (!file.exists(db_path)) { # If the file does not exist, ask about proceeding with download
    # Prompt the user for permission to download the database
    response <- readline(prompt = "NeuroimaGene database not found. It will require ~1.9Gb of space. Do you want to download it from Zenodo? (yes/no): ")
    if (tolower(response) == "yes") {
      message("Downloading database from Zenodo...\n(This step may take >10-15 minutes depending on download speed)")
      message(paste("user determined timeout:", timeout, "seconds"))
      options(timeout = timeout)  # Set timeout for download
      download_success <- FALSE
      tryCatch({
        if (Sys.info()["sysname"] == "Windows") {
          download.file(db_url, db_path, mode = "wb", method = "wininet", quiet = FALSE)
        } else {
          download.file(db_url, db_path, mode = "wb", method = "libcurl", quiet = FALSE)
        }
        if (tools::md5sum(db_path) == '60dab0d523b046f242c0c0f34d918b76') {
          download_success <- TRUE
        }else { file.remove(db_path)
          message("neuroimaGene SQL file was corrupted.")
        }
      }, error = function(e) {
        file.remove(db_path)
        message("Download failed: ", e$message)
      })
      if (!download_success) {
        stop("Database download failed. Please see vignette/check_db() documentation for further options.")
      } else {
        message("Download complete.")
      }
    } else {
      message("Database download was not permitted by the user.")
    }
  } else {
    # Prompt the user for permission to re-download the database
    response <- readline(prompt = "Database already exists locally. Would you like to delete current version and redownload from Zenodo? It will require ~1.9Gb of space. (yes/no): ")
    if (tolower(response) == "yes") {
      message("Deleting current database")
      file.remove(db_path)
      message("Downloading database from Zenodo...\n(This step may take >10-15 minutes depending on download speed)")
      message(paste("user determined timeout:", timeout, "seconds"))
      options(timeout = timeout)  # Set timeout for download
      download_success <- FALSE
      tryCatch({
        if (Sys.info()["sysname"] == "Windows") {
          download.file(db_url, db_path, mode = "wb", method = "wininet", quiet = FALSE)
        } else {
          download.file(db_url, db_path, mode = "wb", method = "libcurl", quiet = FALSE)
        }
        if (tools::md5sum(db_path) == '60dab0d523b046f242c0c0f34d918b76') {
          download_success <- TRUE
        } else { message("neuroimaGene SQL file was corrupted")
        }
      }, error = function(e) {
        file.remove(db_path)
        message("Download failed: ", e$message)
      })
      if (!download_success) {
        stop("Database download failed. Please see vignette/check_db() documentation for further options.")
      } else {
        message("Download complete.")
      }
    } else {
      message("Database download was not permitted by the user.")
    }
  }
}

#' Gene summary plot of neuroimaGene object
#'
#' Generates an overview plot of the neuroimaGene object according to each gene input.
#' @param ng_obj NeuroimaGene Object
#' @param maxGns maximum number of genes to visualize. default=15
#' @param title optional title tag for the plot
#' @param verbose print runtime messages to R console. Default to FALSE
#' @keywords neuroimaging
#' @export
#' @import data.table ggplot2
#' @returns a ggplot class plot detailing NIDPs per gene, colored by brain measure type
#' @examples
#' gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
#' ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
#' plot_gns(ng)
#'
plot_gns <- function(ng_obj, maxGns = 15, title = NA, verbose = FALSE) {
  # initialize column names as null variables
  zscore <- maxZ <- gwas_phenotype <- gene_name <- training_model <- gp_ct <- primary <- NULL

  if(is.na(title)){
    tag <- ''
  } else {
    tag <- paste(' ',as.character(title))
  }
  if(!(is.integer(maxGns) || is.double(maxGns))) {
    stop('maxGns must be of data.type: integer or double', call. = F)
  }

  if (length(unique(ng_obj$gene)) > maxGns ) {
    if(verbose){message(paste('WARNING: Greater than', maxGns, 'genes in input data. Plot will only show the top', maxGns, 'genes ranked by effect size magnitude'))}
    genes <- ng_obj[, list(maxZ = max(zscore)), by = 'gene_name'][order(-abs(maxZ))][1:maxGns,]$gene_name
    ng_obj <- ng_obj[gene_name %in% genes,]
  }

  ng <- data.table::setDT(merge(ng_obj, anno, by = 'gwas_phenotype'))
  ng_summ <- ng[, list(tm_ct = length(unique(training_model)),
                        gp_ct = length(unique(gwas_phenotype))),
                    by = c('gene_name', 'primary')]
  gn_plot <- ggplot2::ggplot(ng_summ, aes(x = gene_name, y = gp_ct, fill = primary, group = primary)) +
    geom_bar(position = position_dodge(preserve = "single"), stat='identity') +
    ggtitle(paste0('GReX measures with neuroimaging correlates', tag)) +
    theme_light()+
    xlab('gene') +
    ylab('NIDPs')

  return(gn_plot)
}

#' List NIDPs
#'
#' Supplies a list of all NIDPs by name for any given modality or atlas
#' @param modality Neuroimaging modality. Defaults to NA; see README for additional options
#' @param atlas Neuroimaging parcellation atlas for NIDP query. Defaults to NA; 
#' see README for additional options
#' @param filename optional filename for writing data to a table
#' @param verbose print runtime messages to R console. Default to FALSE
#' @keywords reference
#' @export
#' @import data.table
#' @importFrom utils write.table
#' @returns a list of NIDP names satisfying the required criteria
#' @examples
#' dk_names <- listNIDPs(modality = 'T1', atlas = 'Desikan')
#'
#'


listNIDPs <- function(modality=NA, atlas=NA, filename = NA, verbose = FALSE) {
  mod <- modality
  atl <- atlas

  #parse input data to determine modality and atlas
    if(!is.na(mod)) {
    if(!(mod %in% unique(anno$modality))) {
      stop(paste(mod, 'modality is not in neuroimaGene repository. see README for all modality types'), call. = F)
    }
    if (!is.na(atl)){
      if(!(atl %in% unique(anno[modality == mod,]$atlas))) {
        stop(paste('The', mod, 'modality does not contain any NIDPs from the', atl,'atlas. see README for description of NIDPs'), call. = F)
      }
      if(verbose){message(paste('using', mod, 'modality and', atl, 'atlas'))}
      nidp_list <- anno[modality == mod & atlas == atl,]$gwas_phenotype
    } else {
      if(verbose){message(paste('using', mod, 'modality only'))}
      nidp_list <- anno[modality == mod,]$gwas_phenotype
    }
  } else if (!is.na(atl)){
    if(!(atl %in% unique(anno$atlas))) {
      stop(paste(atl, ' atlas is not in neuroimaGene repository. See README for all atlas types'), call. = F)
    }
    if(verbose){message(paste('using', atl, 'atlas only'))}
    nidp_list <- anno[atlas == atl,]$gwas_phenotype
  } else {
    if(verbose){message('returning all nidps')}
    nidp_list = anno$gwas_phenotype
  }

  # output .txt file if user requests a file as output.
  if (!is.na(filename)) {
    write.table(nidp_list,
                file = filename,
                append = FALSE,
                quote = FALSE,
                sep = "\t",
                eol = "\n",
                na = '0',
                dec = ".",
                row.names = FALSE,
                col.names = FALSE)
  }

  return(nidp_list)
}

#' Main neuroimaGene query
#'
#' Using a user supplied vector of genes (Ensembl ID's or HUGO names), this 
#' function queries the NeuroimaGene resource for all statistically significant
#' GReX-NIDP associations and returns all findings as a data.table.
#' @param gene_list List of genes to work as inputs. There are no defaults.
#' @param modality Neuroimaging modality for NIDP query. Defaults to T1 structural 
#' NIDPs. Other common options include 'dMRI' for diffusion MRI imaging and 'fMRI'
#' for fucntional MRI image results. 
#' @param atlas Neuroimaging parcellation atlas for NIDP query. Defaults to 
#' Desikan structural atlas. Common T1 atlases include the 'DKT', and 'Destrieux'
#' cortical atlases and 'Subcortex' for freesurfer parcellation of subrotical regions. 
#' See package documentation or vignette for full list. 
#' @param mtc Statistical multiple testing correction for NIDP query. This defaults 
#' to 'BH' for the Benjamini Hochberg False Discovery Rate. Other options include
#' 'BF' for the bonferroni family wise error rate and 'nom' for nominal findings
#' at pvalue <= 0.05. 
#' @param nidps optional user defined vector of target NIDPs to query. Specific 
#' NIDP names can be obtained from the listNIDPnames() function. Use of this
#' parameter overrides the multiple testing correction, returning all nominally 
#' significant findings. 
#' @param filename optional user defined path/filename to which the script will
#' write the nueroimaGene output data table.
#' @param verbose print runtime messages to R console. Default to FALSE
#' @param vignette use for building vignette on installation. Default to FALSE
#' @keywords neuroimaging
#' @export
#' @import data.table DBI stringr RSQLite
#' @importFrom utils write.table
#' @returns a neuroimaGene object: data table with all significant associations between the user provided genes and the UKB NIDPs satisfying the multiple testing correction and atlas/modality/name filters.
#' @examples
#' gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
#' ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
#'
neuroimaGene <- function(gene_list, modality='T1', atlas='Desikan', mtc='BH', nidps = NA, filename = NA, verbose = FALSE, vignette = FALSE) {
# Use included sample data for building vignette prior to download of neuroimaGene data.
  if (vignette){
    return(ng_vignette)
  }

  # check to see if neuroimaGene database has been downloaded and prompt user to download
  pkg_dir <- system.file(package = "neuroimaGene")
  db_path <- file.path(pkg_dir, "extdata", "NeuroimaGenefast.db")
  if (!file.exists(db_path)) {
    check_db()
    }

  if (modality %in% c('all', 'All')){ modality <- NA}
  if (atlas %in% c('all', 'All')){ atlas <- NA}
  if (atlas %in% c('Subcortex', 'subcorted', 'aseg_vol')){atlas <- 'aseg_volume'}

    if (!identical(nidps, NA)) {
    typ <- 'all'
    if(verbose){message(paste('INFO: querying NeuroimaGene for all neuroimaging derived phenotypes',
          '(NIDPs) from the set of provided NIDPs that are associated',
          'with the provided gene list.'))}
  } else if (is.na(atlas)) {
    if (!is.na(modality)){
      typ <- 'mod'
      if(verbose){message(paste('INFO: querying NeuroimaGene for all neuroimaging derived phenotypes',
                  '(NIDPs) from any atlas of the', modality, 'modality that are associated',
                 'with the provided gene list.'))}
       } else {
      typ <- 'all'
      if(verbose){message(paste('INFO: querying NeuroimaGene for all neuroimaging derived phenotypes',
                  '(NIDPs) from all modalities that are associated with the provided',
                  'gene list.'))}
      }
  } else {
    typ <- 'atl'
    if(verbose){message(paste('INFO: querying NeuroimaGene for all neuroimaging derived phenotypes',
                '(NIDPs) from the', atlas,'atlas that are associated with the provided',
                'gene list.'))}
  }

  # parse user parameters for curated set of NIDPs
  if (!identical(nidps, NA) & mtc != 'nom'){
    if(verbose){message(paste('WARNING: automated p-value threshold correction is not valid with',
          'user-defined NIDP sets. Providing results according to a nominal',
          "p-value threshold. (set mtc = 'nom' to avoid this message)"))}
    mtc <- 'nom'
  } else {
    if(verbose){message(paste('INFO: using the study wide', mtc, 'multiple testing correction.'))}
  }

  # parse user parameters for multiple testing,
  if(mtc == 'nom' | !identical(nidps, NA)) {
    colnm = 'pvalue'
    mtctbl = 'nomID'
  } else {
    colnm = paste0(typ, '_', mtc, 'pval')
    mtctbl = paste0(typ, '_', mtc, 'ID')
  }


  # read in TWAS data
  neuroimaGene_db = system.file("extdata", "NeuroimaGenefast.db", package = "neuroimaGene")
  nimg <- DBI::dbConnect(RSQLite::SQLite(), neuroimaGene_db)

  # Select GReX-NIDP associations using user provided parameters
  if (!identical(nidps, NA)) {
    sqlcmd = paste0("SELECT gene, gene_name, gwas_phenotype, training_model, zscore, ", colnm,
                    " FROM (SELECT * FROM Parent WHERE geneID IN (SELECT geneID FROM Genes",
                    " WHERE gene IN (", paste(shQuote(gene_list, type = "sh"), collapse = ', '),
                    ") OR gene_name IN (", paste(shQuote(gene_list, type = "sh"), collapse = ', '),"))",
                    " AND gwas_phenotypeID IN ( SELECT gwas_phenotypeID FROM Nidp WHERE gwas_phenotype IN (", paste(shQuote(nidps, type = "sh"), collapse = ', '),
                    "))) INNER JOIN ",mtctbl," USING(mainID)",
                    " INNER JOIN Tissue USING(training_modelID)",
                    " INNER JOIN Nidp USING(gwas_phenotypeID)" ,
                    " INNER JOIN Genes USING(geneID);")
  } else if (typ == 'atl') {
    sqlcmd = paste0("SELECT gene, gene_name, gwas_phenotype, training_model, zscore, ", colnm,
                    " FROM (SELECT * FROM Parent WHERE geneID IN (SELECT geneID FROM Genes",
                    " WHERE gene IN (", paste(shQuote(gene_list, type = "sh"), collapse = ', '),
                    ") OR gene_name IN (", paste(shQuote(gene_list, type = "sh"), collapse = ', '),")) ",
                    " AND subsetID IN ( SELECT subsetID FROM Subset WHERE atlas = '",atlas,"'))",
                    " INNER JOIN ",mtctbl," USING(mainID)",
                    " INNER JOIN Tissue USING(training_modelID)",
                    " INNER JOIN Nidp USING(gwas_phenotypeID)" ,
                    " INNER JOIN Genes USING(geneID);")

  } else if (typ == 'mod') {
    sqlcmd = paste0("SELECT gene, gene_name, gwas_phenotype, training_model, zscore, ", colnm,
                    " FROM (SELECT * FROM Parent WHERE geneID IN (SELECT geneID FROM Genes",
                    " WHERE gene IN (", paste(shQuote(gene_list, type = "sh"), collapse = ', '),
                    ") OR gene_name IN (", paste(shQuote(gene_list, type = "sh"), collapse = ', '),"))",
                    " AND subsetID IN ( SELECT subsetID FROM Subset WHERE modality = '",modality,"'))",
                    " INNER JOIN ",mtctbl," USING(mainID)",
                    " INNER JOIN Tissue USING(training_modelID)",
                    " INNER JOIN Nidp USING(gwas_phenotypeID)" ,
                    " INNER JOIN Genes USING(geneID);")
  } else {
    sqlcmd = paste0("SELECT gene, gene_name, gwas_phenotype, training_model, zscore, ", colnm,
                    " FROM (SELECT * FROM Parent WHERE geneID IN (SELECT geneID FROM Genes",
                    " WHERE gene IN (", paste(shQuote(gene_list, type = "sh"), collapse = ', '),
                    ") OR gene_name IN (", paste(shQuote(gene_list, type = "sh"), collapse = ', '),")))",
                    " INNER JOIN ",mtctbl," USING(mainID)",
                    " INNER JOIN Tissue USING(training_modelID)",
                    " INNER JOIN Nidp USING(gwas_phenotypeID)" ,
                    " INNER JOIN Genes USING(geneID);")
  }

  assoc = DBI::dbGetQuery(nimg, sqlcmd)
  setDT(assoc)

  if (!is.na(filename)) {
    write.table(assoc,
                file = filename,
                append = FALSE,
                quote = FALSE,
                sep = "\t",
                eol = "\n",
                na = '0',
                dec = ".",
                row.names = FALSE,
                col.names = TRUE)
  }

  #check for missing genes and report
  gn_nm = unique(gene_list)
  assoc_nm = unique(assoc$gene_name)
  assoc_gn = unique(assoc$gene)
  missed = gn_nm[!(gn_nm %in% assoc_nm | gn_nm %in% assoc_gn)]
  if (length(missed) > 0 & verbose) {
    message(paste('WARNING:', length(missed), 'genes in input list do not correspond to an NIDP'))
    message(paste(missed, collapse = ','))
  }
  dbDisconnect(nimg)
  return(assoc)
}

---
title: "neuroimaGene"
output: rmarkdown::html_vignette
resource_files:
  - inst/extdata/vis_abstract.png
vignette: >
  %\VignetteIndexEntry{neuroimaGene}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---


```{r setup, include = FALSE}
library(knitr)
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
  )
```
## Introduction
Hi, Welcome to the NeuroimaGene project!  

The goal of this project is to improve the interpretability of genetic studies relating to neurological and/or psychiatric traits. Analyses such as genome-wide association studies often highlight genetic variants that segregate with disease. Methods such as fine mapping, eQTL colocalization, and transcriptome-wide analyses (TWAS) have been developed to identify the gene level targets of these trait-associated variants. Once a set of gene targets has been identified from GWAS findings, it often remains challenging to identify the biological consequences of variation in these genes. This is the motivation behind neuroimaGene. 



> ![Figure 1: Visual abstract for the NeuroimaGene project](vis_abstract.png)


NeuroimaGene is structured as a searchable repository of associations between neuroimaging features and predicted gene expression measures. Given a list of genes (eg. those associated with Schizophrenia in a recent TWAS) the user can query NeuroimaGene to find neuroimaging measures that are significantly associated with the predicted expression of those genes. This allows the user to translate a list of gene transcripts that are associated with disease to a set of neuroimaging measures. Typically, this neuroimaging is more proximal to the symptoms that patients experience. 

### How does it work? 
For a full explanation, please see our paper, "A Transcriptomic Atlas of the Human Brain Reveals Genetically Determined Aspects of Neuropsychiatric Health." [Bledsoe, 2024](https://doi.org/10.1016/j.ajhg.2024.06.002) A quick overview is as follows. 

The UK bio bank conducted both genetic sequencing and neuroimaging studies of ~40,000 individuals. Relying on these scans, they characterized 3,935 neuroimaging features in each patient. We refer to these as neuroimaging derived phenotypes (NIDPs). NIDPs include structural measures (T1), connectivity measures (dMRI), coactivation measures (fMRI/tfMRI), and more. (see https://www.fmrib.ox.ac.uk/ukbiobank/index.html). Using the set of 33,000 unrelated individuals, Smith et al performed quantitative genome wide association studies for each of the 3,935 NIDPs. Of these, approximately 3,500 had significant SNP based heritability (Smith, 2021). 

We then conduct Joint Tissue Imputation (JTI) informed Transcriptome Wide Association Studies (TWAS) via summary statistics based S-PrediXcan for the >3,500 NIDP GWAS studies (Zhou, 2020). We identify genetically regulated gene expression (GReX) associated with neurological measures observed on MRI imaging. GReX is predicted in 19 different tissue contexts using JTI expression models from 13 neurological 6 neuro-adjacent tissues. The patients comprising the UKB neuroimaging study are 40-69 and were screened for overt neurological pathology. They generally represent an adult population without neurological disease. 

As such, NeuroimaGene catalogs the neurological consequences of lifelong exposure to increases or decreases in gene expression. 

An example association is as follows:
<p>
| gene | gene_name | gwas_phenotype | training_model | zscore | pvalue |
| --- | --- | --- | --- | --- | --- |
| ENSG00000147894 | <span style="color: green;">C9orf72</span> | <span style="color: blue;">AmygNuclei_lh_volume_Basal-nucleus</span> | <span style="color: red;">JTI_Brain_Amygdala</span> | 2.547560 | <span style="color: orange;">0.0108479252</span> |
</p>

	
For the association data described in the table above, the user would read: 

Differential genetically regulated expression of <span style="color: green;">C9orf72</span> in the <span style="color: red;">amygdala</span> is positively associated with the <span style="color: blue;">volume of the basal nucleus of the left amygdala</span> (uncorrected pvalue = <span style="color: orange;">0.011</span>). 

    Outputs: 

    gene: the Ensmble Gene ID
    gene_name: the HUGO gene name 
    gwas_phenotype: the Neuroimaging Derived Phenotype as detailed by the UKB neuroimaging GWAS 
    training_model: the JTI-enriched tissue specific eQTL model in which the association is found
    zscore: The normalized effect size across all tested GRex-NIDP-tissue associations (most appropriate for comparison)
    pvalue: the uncorrected nomiunal pvalue 
    mod_BHpval: the modality-specific Benjamini-Hochberg false-discovery rate corrected association pvalue
    mod_BFpval: the modality-specific Bonferroni corrected association pvalue
    atl_BHpval: the atlas-specific Benjamini-Hochberg false-discovery rate corrected association pvalue
    atl_BFpval: the atlas-specific Bonferroni  corrected association pvalue

## Using the NeuroimaGene R package

The NeuroimaGene R package serves to identify, characterize, and visualize the neurological correlates of genetically regulated gene expression (GReX). These data are stored permanently as a SQL database on Zenodo and need to be integrated into the package for the package to work. <u>To automatically download the database, simply proceed to the next step below.</u> If you run into issues with accessing the db (such as 'Error: no such table: Parent'), then please click on the dropdown menu in this section.

<details>
<summary><b>Troubleshooting the neuroimaGene SQL database</b></summary>


The neuroimaGene SQL database is hosted at the following url: [https://zenodo.org/records/10994978/files/NeuroimaGenefast.db]. It is necessary for the functionality of the package. The preferred way to download the .db file is simply to run a neuroimaGene() query using any genes of interest and to follow the prompts, allowing the package to download the file automatically. This download may fail for any number of reasons including command timeout, connectivity failures, and institutional firewalls. The check_db() function is designed to assist in the acquisition and verification of the .db file. 


**SQL file failed due to timeout**

The neuroimaGene file is large (~1.9GB) and downloading it may take longer than is allotted by the program. The default time limit is 900 seconds (or 15 minutes). If more time is needed, you can specifiy any length using the 'timeout' parameter in the check_db() function. For example, the following command will re-attempt to download the file with 30 minutes of allotted time. 
  `check_db(timeout = 1800)`
  
  
**File is corrupted**

If the neuroimaGene SQL file is corrupted on download, the message "Error: no such table: Parent" message is likely to emerge. There are two approaches to fix this. **First** I would re-run `check_db()`. If the SQL database is present, you will be presented with the option to delete the current file and re-download it fresh from Zenodo. This may be all that is necessary to fix the issue. As with before, you may specify any timeout to give the program time to retrieve the data. If check_db() still does not work, consider manual acquisition of the data file as described below. 

**Manual NeuroimaGene database aqcuisition**

Downloading the package from zenodo using R commands may not work in some computational settings. It is possible to specify a local .db file for use with the neuroimaGene package. You may download the NeuroimaGenefast.db file to your local machine from its zenodo webpage at [https://zenodo.org/records/10994978]. Alternatively, you can download it using curl

`curl -O --output-dir LOCALDIR/  https://zenodo.org/records/10994978/files/NeuroimaGenefast.db`

Once the .dbfile is at LOCALDIR/NeuroimaGenefast.db, you can direct the neuroimaGene R to use the local copy using the following code

`check_db(localdb = 'LOCALDIR/NeuroimaGenefast.db')`

The neuroimaGene package will check the md5 sum of the local copy to see if the file is in tact and if it matches the expected data. If a mismatch is detected, you will be alerted as the file is likely corrupt. Nevertheless, you will be given the option to proceed with integration of the mismatched file if perhaps you have made intentional alterations to the db file and wish to use your own version. 



If issues persist, please do not hesitate to contact me using the following link: [https://github.com/xbledsoe/NeuroimaGene_R/issues/new/choose]



</p>
</details>

### The main neuroimaGene query

The main package function, `neuroimaGene()` takes a vector of gene names (HUGO gene names or ensembl id's) and returns a data table of GReX-NIDP associations that fit a number of user-defined parameters described below: 

  `ng <- neuroimaGene( gene_list, modality='T1', atlas='Desikan', mtc='BH', nidps = NA, filename = NA)`

 
##### Short Parameter Descriptions:
>
> **gene_list**: a vector of gene names (HUGO gene names or ensembl id's). Typically these are associated with a single trait of interest. 
>
> **modality**: the MRI modality used to define the NIDP in the initial UK Biobank imaging protocol. *(See table below for options)*
>  
> **atlas**: the parcellation atlas used to define the NIDPs from the MRI. We use the term "atlas" loosely recognizing that the fMRI data, dMRI data, and T1/T2 data are parcellated in diverse ways. *(See table below for options)*
>  
>  **mtc**: Multiple Testing Correction. Options include Nominal (nom), Benjamini Hochberg (BH), or Bonferroni (BF)
>
> **nidps**: A user-defined list of NIDPs to test. This option overrides the modality and atlas parameters. Default is NA. 
>
> **filename**: A user-defined pathname/filename for text output of the NeuroimaGene results.


<details>
<summary><b>Extended Parameter Descriptions</b></summary>
**Modality and Atlas parameters**

In the process of using the tool, the user is responsible for selecting a subset of NIDPs from the resource for analysis using the `modality` and `atlas` parameters. These parameters allow the user to target specific types of NIDPs such as hippocampal subfields, area and thickness of named cortical regions, fractional anisotropy of named white matter tracts etc. It is recommended to identify the type of brain measure one is interested in prior to performing the gene set analysis.  **The input options for the modality and atlas parameters are detailed in the dropdown table below**

**Multiple Testing Correction Parameter for statistical significance**

In addition to selecting the atlas and modality, neuroimaGene requires a multiple testing threshold correction. Each imaging modality contains a different number of NIDPs (see table above). The Bonferroni correction ('BF') treats each of these NIDPs as independent even though we know through significant data analyses that this is not accurate. This is a highly conservative threshold that will yield high confidence associations but is likely to generate many false negatives. Recognizing the correlation of brain measures from the same modality and atlas, we recommend using the less stringent Benjamini Hochberg ('BH') False Discovery Rate for discovery analyses. The nominal option ('nom') will provide the uncorrected p-value.

Note that the `mtc` parameter represents a study-wide is dynamic, depending on the modality and atlas parameters provided in the initial neuroimaGene query. 

 1. If a user provides an atlas, multiple testing correction will be calculated at an atlas-wide level. 
 
 2. If the user provides a modality but sets the atlas as NA or 'all', multiple testing correction will be calculated at a modality-wide level. 
 
 3. If the user sets the both the modality and atlas to NA or 'all', the correction will be applied to the entire data set. 
 
The above bullet points apply to both the Bonferroni (BF) and Benjamini Hochberg (BH) corrections. Alpha is set to 0.05 in either case. 


**Providing a user selected set of NIDP names**

If the user has a specific set of NIDPs that they would like to assess, the `nidps` parameter receives a vector of NIDPs by name. The NIDP names all include data about the modality, atlas, region, and hemisphere. The names have to be provided in character form and matching must be perfect. To aid with the user-provision of NIDPs, we include the helper utility `listNIDPs()`. This function takes as parameters `modality` and `atlas` and returns a list of all NIDP names that satisfy these criteria. The user can then manually curate a list of desired NIDPs. 

Note that when providing a user-defined set of NIDPs, this option overrides the modality and atlas parameters. This applies both to the set of NIDPs analyze as well as the multiple testing correction. The nominal p-value will be reported as both the Bonferroni and Benjamini-Hochberg corrections that are encoded rely on knowing the set of NIDPs being tested. The user NIDP input violates this assumption and requires the user to identify their own multiple testing threshold. 


</p>
</details>

##### NIDP modality and atlas descriptions:

See dropdown table for NIDP descriptions and source links 

<details><summary><b>NIDP atlas descriptions and source links</b></summary>
<p>

|Modality| Atlas name | # of NIDPs | Description | source | 
| --- | --- | --- | --- | --- |
|T1 | all | 1319 | All measures recorded by the UKB neuroimaging study derived from T1 imaging| see note\*|
|T1 | Destrieux | 444 | Destrieux atlas parcellation of cortical sulci and gyri | [Destrieux](https://doi.org/10.1016/j.neuroimage.2010.06.010) |
|T1 | AmygNuclei | 20 | morphology of Nuclei of the amygdala | [Amygdala nuclei](https://doi.org/10.1016/j.neuroimage.2017.04.046)|
|T1 | Subcortex | 52 | subcortical volumetric segmentation | [aseg_volume](https://doi.org/10.1016/S0896-6273(02)00569-X)|
|T1 | Broadmann | 84 | cortical morphology via Broadmann Areas | [Broadmann](https://doi.org/10.1093/cercor/bhm225)|
|T1 | Desikan | 202 | Desikan Killiany atlas parcellation of cortical morphology | [Desikan](https://doi.org/10.1016/j.neuroimage.2006.01.021)|
|T1 | DKT | 186 | DKT atlas parcellation of cortical morphology | [DKTatlas](https://doi.org/10.3389/fnins.2012.00171)|
|T1 | FAST | 139 | cortical morphology via FMRIB's Automatic Segmentation Tool | [FAST](https://doi.org/10.1109/42.906424)|
|T1 | FIRST | 15 | Subcortical morphology via FIRST | [FIRST](https://doi.org/10.1016/j.neuroimage.2011.02.046)|
|T1 | HippSubfield | 44 | morphology of Hippocampal subfields | [HippSubfield](https://doi.org/10.1016/j.neuroimage.2015.04.042)|
|T1 | pial | 66 | structure: Desikan Killiany atlas of the pial surface | [Desikan](https://doi.org/10.1016/j.neuroimage.2006.01.021)|
|T1 | Brainstem | 5 | structure: Freesurfer brainstem parcellation | [Brainstem](https://doi.org/10.1016/j.neuroimage.2015.02.065)|
|T1 | SIENAX | 10 |structure: Structural Image Evaluation of whole brain measures | [SIENAX](https://doi.org/10.1006/nimg.2002.1040)|
|T1 | ThalamNuclei | 52 | morphology of the Nuclei of the thalamus | [ThalamNuclei](https://doi.org/10.1038/s41597-021-01062-y)|
|dMRI | all | 675 | All measures recorded by the UKB neuroimaging study derived from DWI imaging| see note\*|
|dMRI | ProbtrackX | 243 | white matter mapping obtained via probabilistic tractography | [ProbtrackX](https://doi.org/10.1371/journal.pone.0061892)\*|
|dMRI | TBSS | 432 | white matter mapping obtained via tract-based spatial statistics	 | [TBSS](https://doi.org/10.1016/j.neuroimage.2006.02.024)\*|
|rfMRI | ICA100 | 1485 | functional connectivity using 100 cortical seeds | see note\*|
|rfMRI | ICA25 | 210 | functional connectivity using 25 cortical seeds | see note\*|
|rfMRI | ICA-features | 6 | summary of functional connectivity components | see note\*|
|T2_FLAIR | BIANCA | 1 | white matter hyperintensity classification algorithm | [BIANCA](https://doi.org/10.1016%2Fj.neuroimage.2016.07.018)|
|T2star | SWI | 14 | susceptibility-weighted imaging: microhemorrhage and hemosiderin deposits | see note\*|

\* original publication for details [here](https://doi.org/10.1016/j.neuroimage.2017.10.034) (Alfaro-Almagro, Fidel, et al. "Image processing and Quality Control for the first 10,000 brain imaging datasets from UK Biobank." Neuroimage 166 (2018): 400-424.)

</p>
</details>


### Example NeuroimaGene Query:

```{r}
library(neuroimaGene, quietly = TRUE)
gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)

kable(head(ng, n=6))
```

### Statistical visualizations

##### Genes 

Users may wish to know the comparative contribution of each gene from the provided list to the NeuroimaGene results. We include a function to visualize the number of NIDPs per gene in the neuroimaGene package. 

```{r fig.asp = 0.5, fig.width = 7, out.width = "100%"}
plot_gns(ng, maxGns = 15)

```

<p>
The legend describes the primary measurement of the NIDPs For structural data, this is the cortex, subcortex, CSF, or whole brain measurements. The parameter `maxGns` describes the maximum number of genes to display. It is set to a default of 15. Genes are selected by ranking the neuroimagene genes by their zscore magnitudes and selecting the top N genes.

Note that this plot does not reflect any information on the number of tissue contexts in which the GReX-NIDP association is significant. This data is better captured by the `plot_gnNIDP()` function.

<p>

##### Neuroimaging Derived Phenotypes (NIDPs)
<p>
It is also useful to see what NIDPs are most impacted by the genes provided. The `plot_nidps()` function calculates the mean zscore for each NIDP across all tissue models and genes. It amounts to an aggregated effect of the genes on the region of interest. This linear aggregation is an approximation best understood to show convergence in effect size magnitude and direction. 

```{r fig.asp = 1, fig.width = 8, out.width = "75%"}
plot_nidps(ng, maxNidps = 20)

```

<p>
The legend describes a narrower descriptive profile of the NIDPs than the `plot_gns()` tool. The parameter `maxNidps` describes the maximum number of NIDPs to display. It is set to a default of 30. NIDPs are selected by ranking the NIDPs by their zscore magnitudes and selecting the top N NIDPs. 


##### Genes and Neuroimaging Derived Phenotypes (NIDPs)
<p>
It is also useful to see the intersection of genes and NIDPs. The `plot_gnNIDP()` function shows the number of JTI models in which each GReX-NIDP association is significant.  

```{r fig.asp = 0.8, fig.width = 6, out.width = "75%"}
plot_gnNIDP(ng, maxNidps = 20, maxGns = 15)

```

<p>
The parameter `maxNidps` describes the maximum number of NIDPs to display. It is set to a default of 20. NIDPs are selected by ranking the NIDPs by their zscore magnitudes and selecting the top N NIDPs. The parameter `maxGns` describes the maximum number of genes to display. It is set to a default of 15. Genes are selected by ranking the neuroimagene genes by their zscore magnitudes and selecting the top N genes. 

##### 2-Dimensional brain visualization of GReX-NIDP associations

It is often useful to provide a visual representation of neuroimaging features in their 2-dimensional biological context for presentation purposes. We include the `neuro_vis()` function for this purpose. This function calculates the mean normalized effect size for each NIDP in the neuroimaGene object. The user must provide a number of parameters listed below. 

    ng_obj  - NeuroimaGene object produced by neuroimaGene() function
    atlas   - desired atlas for visualization. (Desikan[default], Subcortex, DKT, Destrieux)
    lowcol  - color for low end of Zscore spectrum. Default is darkred
    midcol  - color for middle of Zscore spectrum. Default is white
    hicol   - color for top end of Zscore spectrum. Default is blue4
  
The function only reflects cortical and subcortical measures. It will automatically separate the NIDPs according to volume, thickness, and surface areas and plot each as its own facet. Please note that this function uses the `ggseg` package and select atlases from the `ggsegExtra` package. Please be sure to cite the creators of ggseg if using this feature in publications.

>Mowinckel AM, Vidal-Piñeiro D (2019). “Visualisation of Brain Statistics with R-packages ggseg and ggseg3d.” 1912.08200.

The `neuro_vis()` function can be used as described below: 

```{r fig.asp = 1, fig.width = 6, out.width = "80%"}
neuro_vis(ng, atlas = 'Desikan', lowcol = 'darkred', midcol = 'white', highcol = 'blue4')

neuro_vis(ng, atlas = 'Subcortex', lowcol = 'darkgreen', midcol = 'yellow2', highcol = 'darkorange')

```

## Limitations
There are several key limitations to this resource that we wish to highlight here.

 * **First**, neuroimaGene describes associations between NIDPs and predicted genetically regulated gene expression (GReX). GReX represents the proportion of gene expression that is genetically determined. Genes that affect a phenotype through protein dysfunction will not show up in neuroimaGene so long as the underlying mRNA expression remains unchanged. 

 * **Second**, the tissue context of the GReX-NIDP association is not causal. GReX-NIDP associations are frequently significant in multiple tissue contexts. In these circumstances, we do not yet have sufficient methods to identify the causal tissue. Even when the GReX measure is only associated with the NIDP in a single tissue, it is important to note that GReX cannot be said to be causal in this tissue without further analyses. 

 * **Third**, while GReX associations are derived from SNP data which is not affected by environment, the S-PrediXcan methodology is still susceptible to confounding from linkage disequilibrium of input SNPs. For causal inference, we recommend applying methods such as MR-JTI (Zhou et al 2020) to the GReX-NIDP associations as a post-hoc test to adjust the association statistics by quantifying and accounting for genetic heterogeneity. 

*Please see our publication for a more extended discussion on limitations.* 

### Terminology

	GWAS  - Genome Wide Association Study
	TWAS  - Transcriptome Wide Association Study
	GReX  - Genetically regulated gene expression
	JTI   - Joint Tissue Imputation (link)
	NIDP  - Neuroimaging Derived Phenotype
	MRI   - Magnetic resonance imaging
	T1    - MRI modality classically used for structural characterization of the brain
	dMRI  - diffusion weighted MRI (used in our data for white matter tractography)
	fMRI  - functional MRI used for examining coordinated activity across regions of the brain 
	UKB   - United Kingdom Biobank
	eQTL  - expression Quantitative Trait Locus
	GTEx  - Genotype Tissue Expression Consortium
	

#### Associated papers for further reading

Barbeira, Alvaro N., et al. "Exploring the phenotypic consequences of tissue specific gene expression variation inferred from GWAS summary statistics." Nature communications 9.1 (2018): 1-20.

Zhou, Dan, et al. "A unified framework for joint-tissue transcriptome-wide association and Mendelian randomization analysis." Nature genetics 52.11 (2020): 1239-1246.

Miller, Karla L., et al. "Multimodal population brain imaging in the UK Biobank prospective epidemiological study." Nature neuroscience 19.11 (2016): 1523-1536.

Smith, Stephen M., et al. "An expanded set of genome-wide association studies of brain imaging phenotypes in UK Biobank." Nature neuroscience 24.5 (2021): 737-745.

Elliott, Lloyd T., et al. "Genome-wide association studies of brain imaging phenotypes in UK Biobank." Nature 562.7726 (2018): 210-216.

Gamazon, Eric R., et al. "Multi-tissue transcriptome analyses identify genetic mechanisms underlying neuropsychiatric traits." Nature genetics 51.6 (2019): 933-940.

Mowinckel, Athanasia M., and Didac Vidal-Piñeiro. "Visualization of brain statistics with R packages ggseg and ggseg3d." Advances in Methods and Practices in Psychological Science 3.4 (2020): 466-483.

>Please direct all questions to me at the following email: xbledsoe22@gmail.com

---
title: "neuroimaGene"
output: rmarkdown::html_vignette
resource_files:
  - inst/extdata/vis_abstract.png
vignette: >
  %\VignetteIndexEntry{neuroimaGene}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---


```{r setup, include = FALSE}
library(knitr)
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
  )
```
## Introduction
Hi, Welcome to the NeuroimaGene project!  

The goal of this project is to improve the interpretability of genetic studies relating to neurological and/or psychiatric traits. Analyses such as genome-wide association studies often highlight genetic variants that segregate with disease. Methods such as fine mapping, eQTL colocalization, and transcriptome-wide analyses (TWAS) have been developed to identify the gene level targets of these trait-associated variants. Once a set of gene targets has been identified from GWAS findings, it often remains challenging to identify the biological consequences of variation in these genes. This is the motivation behind neuroimaGene. 



> ![Figure 1: Visual abstract for the NeuroimaGene project](vis_abstract.png)


NeuroimaGene is structured as a searchable repository of associations between neuroimaging features and predicted gene expression measures. Given a list of genes (eg. those associated with Schizophrenia in a recent TWAS) the user can query NeuroimaGene to find neuroimaging measures that are significantly associated with the predicted expression of those genes. This allows the user to translate a list of gene transcripts that are associated with disease to a set of neuroimaging measures. Typically, this neuroimaging is more proximal to the symptoms that patients experience. 

### How does it work? 
For a full explanation, please see our paper, "A Transcriptomic Atlas of the Human Brain Reveals Genetically Determined Aspects of Neuropsychiatric Health." [Bledsoe, 2024](https://doi.org/10.1016/j.ajhg.2024.06.002) A quick overview is as follows. 

The UK bio bank conducted both genetic sequencing and neuroimaging studies of ~40,000 individuals. Relying on these scans, they characterized 3,935 neuroimaging features in each patient. We refer to these as neuroimaging derived phenotypes (NIDPs). NIDPs include structural measures (T1), connectivity measures (dMRI), coactivation measures (fMRI/tfMRI), and more. (see https://www.fmrib.ox.ac.uk/ukbiobank/index.html). Using the set of 33,000 unrelated individuals, Smith et al performed quantitative genome wide association studies for each of the 3,935 NIDPs. Of these, approximately 3,500 had significant SNP based heritability (Smith, 2021). 

We then conduct Joint Tissue Imputation (JTI) informed Transcriptome Wide Association Studies (TWAS) via summary statistics based S-PrediXcan for the >3,500 NIDP GWAS studies (Zhou, 2020). We identify genetically regulated gene expression (GReX) associated with neurological measures observed on MRI imaging. GReX is predicted in 19 different tissue contexts using JTI expression models from 13 neurological 6 neuro-adjacent tissues. The patients comprising the UKB neuroimaging study are 40-69 and were screened for overt neurological pathology. They generally represent an adult population without neurological disease. 

As such, NeuroimaGene catalogs the neurological consequences of lifelong exposure to increases or decreases in gene expression. 

An example association is as follows:
<p>
| gene | gene_name | gwas_phenotype | training_model | zscore | pvalue |
| --- | --- | --- | --- | --- | --- |
| ENSG00000147894 | <span style="color: green;">C9orf72</span> | <span style="color: blue;">AmygNuclei_lh_volume_Basal-nucleus</span> | <span style="color: red;">JTI_Brain_Amygdala</span> | 2.547560 | <span style="color: orange;">0.0108479252</span> |
</p>

	
For the association data described in the table above, the user would read: 

Differential genetically regulated expression of <span style="color: green;">C9orf72</span> in the <span style="color: red;">amygdala</span> is positively associated with the <span style="color: blue;">volume of the basal nucleus of the left amygdala</span> (uncorrected pvalue = <span style="color: orange;">0.011</span>). 

    Outputs: 

    gene: the Ensmble Gene ID
    gene_name: the HUGO gene name 
    gwas_phenotype: the Neuroimaging Derived Phenotype as detailed by the UKB neuroimaging GWAS 
    training_model: the JTI-enriched tissue specific eQTL model in which the association is found
    zscore: The normalized effect size across all tested GRex-NIDP-tissue associations (most appropriate for comparison)
    pvalue: the uncorrected nomiunal pvalue 
    mod_BHpval: the modality-specific Benjamini-Hochberg false-discovery rate corrected association pvalue
    mod_BFpval: the modality-specific Bonferroni corrected association pvalue
    atl_BHpval: the atlas-specific Benjamini-Hochberg false-discovery rate corrected association pvalue
    atl_BFpval: the atlas-specific Bonferroni  corrected association pvalue

## Using the NeuroimaGene R package

The NeuroimaGene R package serves to identify, characterize, and visualize the neurological correlates of genetically regulated gene expression (GReX). The following functions serve this goal.

### The main neuroimaGene query

The main package function, `neuroimaGene()` takes a vector of gene names (HUGO gene names or ensembl id's) and returns a data table of GReX-NIDP associations that fit a number of user-defined parameters described below: 

  `ng <- neuroimaGene( gene_list, modality='T1', atlas='Desikan', mtc='BH', nidps = NA, filename = NA)`

 
##### Short Parameter Descriptions:
>
> **gene_list**: a vector of gene names (HUGO gene names or ensembl id's). Typically these are associated with a single trait of interest. 
>
> **modality**: the MRI modality used to define the NIDP in the initial UK Biobank imaging protocol. *(See table below for options)*
>  
> **atlas**: the parcellation atlas used to define the NIDPs from the MRI. We use the term "atlas" loosely recognizing that the fMRI data, dMRI data, and T1/T2 data are parcellated in diverse ways. *(See table below for options)*
>  
>  **mtc**: Multiple Testing Correction. Options include Nominal (nom), Benjamini Hochberg (BH), or Bonferroni (BF)
>
> **nidps**: A user-defined list of NIDPs to test. This option overrides the modality and atlas parameters. Default is NA. 
>
> **filename**: A user-defined pathname/filename for text output of the NeuroimaGene results.


<details>
<summary><b>Extended Parameter Descriptions</b></summary>
**Modality and Atlas parameters**

In the process of using the tool, the user is responsible for selecting a subset of NIDPs from the resource for analysis using the `modality` and `atlas` parameters. These parameters allow the user to target specific types of NIDPs such as hippocampal subfields, area and thickness of named cortical regions, fractional anisotropy of named white matter tracts etc. It is recommended to identify the type of brain measure one is interested in prior to performing the gene set analysis.  **The input options for the modality and atlas parameters are detailed in the dropdown table below**

**Multiple Testing Correction Parameter for statistical significance**

In addition to selecting the atlas and modality, neuroimaGene requires a multiple testing threshold correction. Each imaging modality contains a different number of NIDPs (see table above). The Bonferroni correction ('BF') treats each of these NIDPs as independent even though we know through significant data analyses that this is not accurate. This is a highly conservative threshold that will yield high confidence associations but is likely to generate many false negatives. Recognizing the correlation of brain measures from the same modality and atlas, we recommend using the less stringent Benjamini Hochberg ('BH') False Discovery Rate for discovery analyses. The nominal option ('nom') will provide the uncorrected p-value.

Note that the `mtc` parameter represents a study-wide is dynamic, depending on the modality and atlas parameters provided in the initial neuroimaGene query. 

 1. If a user provides an atlas, multiple testing correction will be calculated at an atlas-wide level. 
 
 2. If the user provides a modality but sets the atlas as NA or 'all', multiple testing correction will be calculated at a modality-wide level. 
 
 3. If the user sets the both the modality and atlas to NA or 'all', the correction will be applied to the entire data set. 
 
The above bullet points apply to both the Bonferroni (BF) and Benjamini Hochberg (BH) corrections. Alpha is set to 0.05 in either case. 


**Providing a user selected set of NIDP names**

If the user has a specific set of NIDPs that they would like to assess, the `nidps` parameter receives a vector of NIDPs by name. The NIDP names all include data about the modality, atlas, region, and hemisphere. The names have to be provided in character form and matching must be perfect. To aid with the user-provision of NIDPs, we include the helper utility `listNIDPs()`. This function takes as parameters `modality` and `atlas` and returns a list of all NIDP names that satisfy these criteria. The user can then manually curate a list of desired NIDPs. 

Note that when providing a user-defined set of NIDPs, this option overrides the modality and atlas parameters. This applies both to the set of NIDPs analyze as well as the multiple testing correction. The nominal p-value will be reported as both the Bonferroni and Benjamini-Hochberg corrections that are encoded rely on knowing the set of NIDPs being tested. The user NIDP input violates this assumption and requires the user to identify their own multiple testing threshold. 


</p>
</details>

##### NIDP modality and atlas descriptions:

See dropdown table for NIDP descriptions and source links 

<details><summary><b>NIDP atlas descriptions and source links</b></summary>
<p>

|Modality| Atlas name | # of NIDPs | Description | source | 
| --- | --- | --- | --- | --- |
|T1 | all | 1319 | All measures recorded by the UKB neuroimaging study derived from T1 imaging| see note\*|
|T1 | Destrieux | 444 | Destrieux atlas parcellation of cortical sulci and gyri | [Destrieux](https://doi.org/10.1016/j.neuroimage.2010.06.010) |
|T1 | AmygNuclei | 20 | morphology of Nuclei of the amygdala | [Amygdala nuclei](https://doi.org/10.1016/j.neuroimage.2017.04.046)|
|T1 | Subcortex | 52 | subcortical volumetric segmentation | [aseg_volume](https://doi.org/10.1016/S0896-6273(02)00569-X)|
|T1 | Broadmann | 84 | cortical morphology via Broadmann Areas | [Broadmann](https://doi.org/10.1093/cercor/bhm225)|
|T1 | Desikan | 202 | Desikan Killiany atlas parcellation of cortical morphology | [Desikan](https://doi.org/10.1016/j.neuroimage.2006.01.021)|
|T1 | DKT | 186 | DKT atlas parcellation of cortical morphology | [DKTatlas](https://doi.org/10.3389/fnins.2012.00171)|
|T1 | FAST | 139 | cortical morphology via FMRIB's Automatic Segmentation Tool | [FAST](https://doi.org/10.1109/42.906424)|
|T1 | FIRST | 15 | Subcortical morphology via FIRST | [FIRST](https://doi.org/10.1016/j.neuroimage.2011.02.046)|
|T1 | HippSubfield | 44 | morphology of Hippocampal subfields | [HippSubfield](https://doi.org/10.1016/j.neuroimage.2015.04.042)|
|T1 | pial | 66 | structure: Desikan Killiany atlas of the pial surface | [Desikan](https://doi.org/10.1016/j.neuroimage.2006.01.021)|
|T1 | Brainstem | 5 | structure: Freesurfer brainstem parcellation | [Brainstem](https://doi.org/10.1016/j.neuroimage.2015.02.065)|
|T1 | SIENAX | 10 |structure: Structural Image Evaluation of whole brain measures | [SIENAX](https://doi.org/10.1006/nimg.2002.1040)|
|T1 | ThalamNuclei | 52 | morphology of the Nuclei of the thalamus | [ThalamNuclei](https://doi.org/10.1038/s41597-021-01062-y)|
|dMRI | all | 675 | All measures recorded by the UKB neuroimaging study derived from DWI imaging| see note\*|
|dMRI | ProbtrackX | 243 | white matter mapping obtained via probabilistic tractography | [ProbtrackX](https://doi.org/10.1371/journal.pone.0061892)\*|
|dMRI | TBSS | 432 | white matter mapping obtained via tract-based spatial statistics	 | [TBSS](https://doi.org/10.1016/j.neuroimage.2006.02.024)\*|
|rfMRI | ICA100 | 1485 | functional connectivity using 100 cortical seeds | see note\*|
|rfMRI | ICA25 | 210 | functional connectivity using 25 cortical seeds | see note\*|
|rfMRI | ICA-features | 6 | summary of functional connectivity components | see note\*|
|T2_FLAIR | BIANCA | 1 | white matter hyperintensity classification algorithm | [BIANCA](https://doi.org/10.1016%2Fj.neuroimage.2016.07.018)|
|T2star | SWI | 14 | susceptibility-weighted imaging: microhemorrhage and hemosiderin deposits | see note\*|

\* original publication for details [here](https://doi.org/10.1016/j.neuroimage.2017.10.034) (Alfaro-Almagro, Fidel, et al. "Image processing and Quality Control for the first 10,000 brain imaging datasets from UK Biobank." Neuroimage 166 (2018): 400-424.)

</p>
</details>


### Example NeuroimaGene Query:

```{r}
library(neuroimaGene, quietly = TRUE)
gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)

kable(head(ng, n=6))
```

### Statistical visualizations

##### Genes 

Users may wish to know the comparative contribution of each gene from the provided list to the NeuroimaGene results. We include a function to visualize the number of NIDPs per gene in the neuroimaGene package. 

```{r fig.asp = 0.5, fig.width = 7, out.width = "100%"}
plot_gns(ng, maxGns = 15)

```

<p>
The legend describes the primary measurement of the NIDPs For structural data, this is the cortex, subcortex, CSF, or whole brain measurements. The parameter `maxGns` describes the maximum number of genes to display. It is set to a default of 15. Genes are selected by ranking the neuroimagene genes by their zscore magnitudes and selecting the top N genes.

Note that this plot does not reflect any information on the number of tissue contexts in which the GReX-NIDP association is significant. This data is better captured by the `plot_gnNIDP()` function.

<p>

##### Neuroimaging Derived Phenotypes (NIDPs)
<p>
It is also useful to see what NIDPs are most impacted by the genes provided. The `plot_nidps()` function calculates the mean zscore for each NIDP across all tissue models and genes. It amounts to an aggregated effect of the genes on the region of interest. This linear aggregation is an approximation best understood to show convergence in effect size magnitude and direction. 

```{r fig.asp = 1, fig.width = 8, out.width = "75%"}
plot_nidps(ng, maxNidps = 20)

```

<p>
The legend describes a narrower descriptive profile of the NIDPs than the `plot_gns()` tool. The parameter `maxNidps` describes the maximum number of NIDPs to display. It is set to a default of 30. NIDPs are selected by ranking the NIDPs by their zscore magnitudes and selecting the top N NIDPs. 


##### Genes and Neuroimaging Derived Phenotypes (NIDPs)
<p>
It is also useful to see the intersection of genes and NIDPs. The `plot_gnNIDP()` function shows the number of JTI models in which each GReX-NIDP association is significant.  

```{r fig.asp = 0.8, fig.width = 6, out.width = "75%"}
plot_gnNIDP(ng, maxNidps = 20, maxGns = 15)

```

<p>
The parameter `maxNidps` describes the maximum number of NIDPs to display. It is set to a default of 20. NIDPs are selected by ranking the NIDPs by their zscore magnitudes and selecting the top N NIDPs. The parameter `maxGns` describes the maximum number of genes to display. It is set to a default of 15. Genes are selected by ranking the neuroimagene genes by their zscore magnitudes and selecting the top N genes. 

##### 2-Dimensional brain visualization of GReX-NIDP associations

It is often useful to provide a visual representation of neuroimaging features in their 2-dimensional biological context for presentation purposes. We include the `neuro_vis()` function for this purpose. This function calculates the mean normalized effect size for each NIDP in the neuroimaGene object. The user must provide a number of parameters listed below. 

    ng_obj  - NeuroimaGene object produced by neuroimaGene() function
    atlas   - desired atlas for visualization. (Desikan[default], Subcortex, DKT, Destrieux)
    lowcol  - color for low end of Zscore spectrum. Default is darkred
    midcol  - color for middle of Zscore spectrum. Default is white
    hicol   - color for top end of Zscore spectrum. Default is blue4
  
The function only reflects cortical and subcortical measures. It will automatically separate the NIDPs according to volume, thickness, and surface areas and plot each as its own facet. Please note that this function uses the `ggseg` package and select atlases from the `ggsegExtra` package. Please be sure to cite the creators of ggseg if using this feature in publications.

>Mowinckel AM, Vidal-Piñeiro D (2019). “Visualisation of Brain Statistics with R-packages ggseg and ggseg3d.” 1912.08200.

The `neuro_vis()` function can be used as described below: 

```{r fig.asp = 0.4, fig.width = 6, out.width = "80%"}
neuro_vis(ng, atlas = 'Desikan', lowcol = 'darkred', midcol = 'white', highcol = 'blue4')

neuro_vis(ng, atlas = 'Subcortex', lowcol = 'darkgreen', midcol = 'yellow2', highcol = 'darkorange')

```

## Limitations
There are several key limitations to this resource that we wish to highlight here.

 * **First**, neuroimaGene describes associations between NIDPs and predicted genetically regulated gene expression (GReX). GReX represents the proportion of gene expression that is genetically determined. Genes that affect a phenotype through protein dysfunction will not show up in neuroimaGene so long as the underlying mRNA expression remains unchanged. 

 * **Second**, the tissue context of the GReX-NIDP association is not causal. GReX-NIDP associations are frequently significant in multiple tissue contexts. In these circumstances, we do not yet have sufficient methods to identify the causal tissue. Even when the GReX measure is only associated with the NIDP in a single tissue, it is important to note that GReX cannot be said to be causal in this tissue without further analyses. 

 * **Third**, while GReX associations are derived from SNP data which is not affected by environment, the S-PrediXcan methodology is still susceptible to confounding from linkage disequilibrium of input SNPs. For causal inference, we recommend applying methods such as MR-JTI (Zhou et al 2020) to the GReX-NIDP associations as a post-hoc test to adjust the association statistics by quantifying and accounting for genetic heterogeneity. 

*Please see our publication for a more extended discussion on limitations.* 

### Terminology

	GWAS  - Genome Wide Association Study
	TWAS  - Transcriptome Wide Association Study
	GReX  - Genetically regulated gene expression
	JTI   - Joint Tissue Imputation (link)
	NIDP  - Neuroimaging Derived Phenotype
	MRI   - Magnetic resonance imaging
	T1    - MRI modality classically used for structural characterization of the brain
	dMRI  - diffusion weighted MRI (used in our data for white matter tractography)
	fMRI  - functional MRI used for examining coordinated activity across regions of the brain 
	UKB   - United Kingdom Biobank
	eQTL  - expression Quantitative Trait Locus
	GTEx  - Genotype Tissue Expression Consortium
	

#### Associated papers for further reading

Barbeira, Alvaro N., et al. "Exploring the phenotypic consequences of tissue specific gene expression variation inferred from GWAS summary statistics." Nature communications 9.1 (2018): 1-20.

Zhou, Dan, et al. "A unified framework for joint-tissue transcriptome-wide association and Mendelian randomization analysis." Nature genetics 52.11 (2020): 1239-1246.

Miller, Karla L., et al. "Multimodal population brain imaging in the UK Biobank prospective epidemiological study." Nature neuroscience 19.11 (2016): 1523-1536.

Smith, Stephen M., et al. "An expanded set of genome-wide association studies of brain imaging phenotypes in UK Biobank." Nature neuroscience 24.5 (2021): 737-745.

Elliott, Lloyd T., et al. "Genome-wide association studies of brain imaging phenotypes in UK Biobank." Nature 562.7726 (2018): 210-216.

Gamazon, Eric R., et al. "Multi-tissue transcriptome analyses identify genetic mechanisms underlying neuropsychiatric traits." Nature genetics 51.6 (2019): 933-940.

Mowinckel, Athanasia M., and Didac Vidal-Piñeiro. "Visualization of brain statistics with R packages ggseg and ggseg3d." Advances in Methods and Practices in Psychological Science 3.4 (2020): 466-483.

>Please direct all questions to me at the following email: xbledsoe22@gmail.com

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/neuro_vis.R
\name{neuro_vis}
\alias{neuro_vis}
\title{2D visualization plot of a neuroimaGene object}
\usage{
neuro_vis(
  ng_obj,
  atlas = "Desikan",
  lowcol = "red2",
  midcol = "white",
  highcol = "royalblue2",
  title = NA
)
}
\arguments{
\item{ng_obj}{NeuroimaGene object produced by neuroimaGene() function}

\item{atlas}{desired atlas for visualization. Desikan (default), Subcortex, DKT, Destrieux.}

\item{lowcol}{color for low end of Zscore spectrum. Default is red}

\item{midcol}{color for middle of Zscore spectrum. Default is white}

\item{highcol}{color for top end of Zscore spectrum. Default is blue}

\item{title}{optional title tag for the plot}
}
\value{
class: ggplot object depicting 2D visualization of the NIDPs from the neuroimaGene object portrayed on the brain and shaded by mean effect size.
}
\description{
Generates a 2D visualization plot of the neuroimaGene object. Neuroimaging
regions are defined by the atlas parameter and colored according to the
magnitude and direction of the aggregate effect from each gene in the
NeuroimaGene object. Colors can be defined by the user.
}
\examples{
gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
neuro_vis(ng, atlas = 'DKT')


}
\keyword{neuroimaging}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ng_vignette_doc.R
\docType{data}
\name{ng_vignette}
\alias{ng_vignette}
\title{NeuroimaGene object for vignette illustration}
\format{
A data.table with 6 columns and 3824 rows:
\describe{
  \item{gene}{character: ENSEMBL Gene ID}
  \item{gene_name}{character: HUGO gene name}
  \item{gwas_phenotype}{character: neuroimaging derived phenotype}
  \item{training_model}{character: JTI derived tissue gene expression model}
  \item{zscore}{numeric: normalized effect size of GReX on NIDP morphology}
  \item{mod_BHpval}{character: Benjamini Hochberg corrected pvalue corrected by modality }
}
}
\source{
Bledsoe, X. (2024) A transcriptomic atlas of the human brain reveals genetically determined aspects of neuropsychiatric health
}
\usage{
data(ng_vignette)
}
\value{
This script has no return. This is a documentation file for the
neuroimaGene data subset required to build the vignette.
}
\description{
NeuroimaGene data table containing select associations used in the package vignette.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/neuroimagene_pkg.R
\name{neuroimaGene}
\alias{neuroimaGene}
\title{Main neuroimaGene query}
\usage{
neuroimaGene(
  gene_list,
  modality = "T1",
  atlas = "Desikan",
  mtc = "BH",
  nidps = NA,
  filename = NA,
  verbose = FALSE,
  vignette = FALSE
)
}
\arguments{
\item{gene_list}{List of genes to work as inputs. There are no defaults.}

\item{modality}{Neuroimaging modality for NIDP query. Defaults to T1 structural 
NIDPs. Other common options include 'dMRI' for diffusion MRI imaging and 'fMRI'
for fucntional MRI image results.}

\item{atlas}{Neuroimaging parcellation atlas for NIDP query. Defaults to 
Desikan structural atlas. Common T1 atlases include the 'DKT', and 'Destrieux'
cortical atlases and 'Subcortex' for freesurfer parcellation of subrotical regions. 
See package documentation or vignette for full list.}

\item{mtc}{Statistical multiple testing correction for NIDP query. This defaults 
to 'BH' for the Benjamini Hochberg False Discovery Rate. Other options include
'BF' for the bonferroni family wise error rate and 'nom' for nominal findings
at pvalue <= 0.05.}

\item{nidps}{optional user defined vector of target NIDPs to query. Specific 
NIDP names can be obtained from the listNIDPnames() function. Use of this
parameter overrides the multiple testing correction, returning all nominally 
significant findings.}

\item{filename}{optional user defined path/filename to which the script will
write the nueroimaGene output data table.}

\item{verbose}{print runtime messages to R console. Default to FALSE}

\item{vignette}{use for building vignette on installation. Default to FALSE}
}
\value{
a neuroimaGene object: data table with all significant associations between the user provided genes and the UKB NIDPs satisfying the multiple testing correction and atlas/modality/name filters.
}
\description{
Using a user supplied vector of genes (Ensembl ID's or HUGO names), this 
function queries the NeuroimaGene resource for all statistically significant
GReX-NIDP associations and returns all findings as a data.table.
}
\examples{
gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)

}
\keyword{neuroimaging}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_gn_nidp.R
\name{plot_gnNIDP}
\alias{plot_gnNIDP}
\title{Gene by NIDP summary plot of neuroimaGene object}
\usage{
plot_gnNIDP(
  ng_obj,
  maxNidps = 20,
  maxGns = 15,
  title = NA,
  shortnames = TRUE,
  verbose = FALSE
)
}
\arguments{
\item{ng_obj}{NeuroimaGene object}

\item{maxNidps}{maximum number of NIDPs to visualize. default=20}

\item{maxGns}{maximum number of genes to visualize. default=15}

\item{title}{optional title tag for the plot}

\item{shortnames}{optional boolean tag for simplified names. Default to TRUE}

\item{verbose}{print runtime messages to R console. Default to FALSE}
}
\value{
a ggplot class heatmap showing tissue models per NIDP/Gene pair
}
\description{
Generate overview plot of the neuroimagene object according to gene/NIDP pair
}
\examples{
gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
plot_gnNIDP(ng)

}
\keyword{neuroimaging}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/anno_doc.R
\docType{data}
\name{anno}
\alias{anno}
\title{NIDP annotation data}
\format{
A data.table with 10 columns and 3935 rows:
\describe{
  \item{gwas_phenotype}{character: UKB-derived neuroimaging derived phenotype (NIDP)}
  \item{modality}{character: MRI neuroimaging modality}
  \item{atlas}{character: neuroimaging cortical atlas}
  \item{side}{character: right or left hemisphere or midline/whole brain}
  \item{primary}{character: primary cortical region}
  \item{secondary}{character: secondary cortical region}
  \item{region}{character: named region of the brain}
  \item{measurement}{character: morphology measurement}
  \item{fMRI_node_1}{character: fMRI node 1}
  \item{fMRI_node_2}{character: fMRI node 2}
  \item{NIDP}{character: user-friendly name for each NIDP}
}
}
\source{
Bledsoe, X. (2024) A transcriptomic atlas of the human brain reveals genetically determined aspects of neuropsychiatric health
}
\value{
This script has no return. This is a documentation file for the
annotation dataset for all neuroimaging derived phenotypes.
}
\description{
annotation data for all NIDPs taken from the UKbiobank
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_nidps.R
\name{plot_nidps}
\alias{plot_nidps}
\title{NIDP summary plot of NeuroimaGene object}
\usage{
plot_nidps(
  ng_obj,
  maxNidps = 30,
  title = NA,
  shortnames = TRUE,
  mag = TRUE,
  verbose = FALSE
)
}
\arguments{
\item{ng_obj}{NeuroimaGene Object}

\item{maxNidps}{maximum number of NIDPs to visualize. default=30}

\item{title}{optional title tag for the plot}

\item{shortnames}{optional boolean tag for simplified names. Default to TRUE}

\item{mag}{boolean to present effect sizes by magnitude rather than as a vector. Default to TRUE}

\item{verbose}{print runtime messages to R console. Default to FALSE}
}
\value{
a ggplot class object detailing mean effect size magnitude per NIDP, colored by brain region
}
\description{
Generate overview plot of the neuroimagene object according to nidps
}
\examples{
gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
plot_nidps(ng)

}
\keyword{neuroimaging}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_db.R
\name{check_db}
\alias{check_db}
\title{Check neuroimaGene database downloaded}
\usage{
check_db(timeout = 900)
}
\arguments{
\item{timeout}{time to spend downloading the NeuroimaGene database in seconds (default = 900)}
}
\value{
no return value, called to give information on status of neuroimaGene
database and prompt user the user to download if resource file is missing.
}
\description{
Check if the NeuroimaGene database exists in the proper location prior to running the query and prompt user to download if not.
}
\examples{
check_db(timeout = 600)
}
\keyword{installation}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_gns.R
\name{plot_gns}
\alias{plot_gns}
\title{Gene summary plot of neuroimaGene object}
\usage{
plot_gns(ng_obj, maxGns = 15, title = NA, verbose = FALSE)
}
\arguments{
\item{ng_obj}{NeuroimaGene Object}

\item{maxGns}{maximum number of genes to visualize. default=15}

\item{title}{optional title tag for the plot}

\item{verbose}{print runtime messages to R console. Default to FALSE}
}
\value{
a ggplot class plot detailing NIDPs per gene, colored by brain measure type
}
\description{
Generates an overview plot of the neuroimaGene object according to each gene input.
}
\examples{
gene_list <- c('TRIM35', 'PROSER3', 'EXOSC6', 'PICK1', 'UPK1A', 'ESPNL', 'ZIC4')
ng <- neuroimaGene(gene_list, atlas = NA, mtc = 'BH', vignette = TRUE)
plot_gns(ng)

}
\keyword{neuroimaging}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fs_anno_doc.R
\docType{data}
\name{fs_anno}
\alias{fs_anno}
\title{NIDP freesurfer annotation data}
\format{
A data.table with 7 columns and 890 rows:
\describe{
  \item{gwas_phenotype}{character: UKB-derived neuroimaging derived phenotype}
  \item{atl}{character: neuroimaging cortical atlas}
  \item{hemisphere}{character: right or left hemisphere or midline/whole brain}
  \item{secondary}{character: secondary cortical region}
  \item{fs_name}{character: freesurfer name}
  \item{label}{character: label name for the region}
  \item{atlas}{character: freesurfer name for neuroimaging cortical atlas}
}
}
\source{
Bledsoe, X. (2024) A transcriptomic atlas of the human brain reveals genetically determined aspects of neuropsychiatric health
}
\usage{
data(fs_anno)
}
\value{
This script has no return. This is a documentation file for the
annotation dataset for all neuroimaging derived phenotypes in the fsbrain package.
}
\description{
Freesurfer names for select cortical and subcortical NIDPs
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/NIDP_names.R
\name{listNIDPs}
\alias{listNIDPs}
\title{List NIDPs}
\usage{
listNIDPs(modality = NA, atlas = NA, filename = NA, verbose = FALSE)
}
\arguments{
\item{modality}{Neuroimaging modality. Defaults to NA; see README for additional options}

\item{atlas}{Neuroimaging parcellation atlas for NIDP query. Defaults to NA; 
see README for additional options}

\item{filename}{optional filename for writing data to a table}

\item{verbose}{print runtime messages to R console. Default to FALSE}
}
\value{
a list of NIDP names satisfying the required criteria
}
\description{
Supplies a list of all NIDPs by name for any given modality or atlas
}
\examples{
dk_names <- listNIDPs(modality = 'T1', atlas = 'Desikan')


}
\keyword{reference}
